durationtools.positive_integer_to_implied_prolation_multipler
=============================================================

.. autofunction:: abjad.tools.durationtools.positive_integer_to_implied_prolation_multipler.positive_integer_to_implied_prolation_multipler
